Office Conversion
Various backends for converting files from office formats to PDF formats
Environment Variables
DOCBOX_OFFICE_CONVERTER- “server” to use a convert_server or “lambda” to use “convert_lambda”
See individual modules for service specific environment variables
Modules
- convert_
lambda - Convert Lambda
- convert_
server - Convert Server
- libreoffice
Structs
Enums
Functions
- is_
pdf_ compatible - Checks if the provided mime type either is a PDF or can be converted to a PDF
- process_
office - Processes a PDF compatible office/other supported file format. Converts to PDF then processes as a PDF with process_pdf