Module convert_lambda

Module convert_lambda 

Convert Lambda

Lambda based file conversion server https://github.com/jacobtread/office-convert-lambda backend for performing office file conversion

Environment Variables

  • DOCBOX_CONVERT_LAMBDA_TMP_BUCKET - S3 bucket to store the temporary input and output files from conversion
  • DOCBOX_CONVERT_LAMBDA_FUNCTION_NAME - The name or ARN of the Lambda function, version, or alias.
  • DOCBOX_CONVERT_LAMBDA_QUALIFIER - Optionally specify a version or alias to invoke a published version of the function.
  • DOCBOX_CONVERT_LAMBDA_TENANT_ID - Optional identifier of the tenant in a multi-tenant Lambda function.
  • DOCBOX_CONVERT_LAMBDA_RETRY_ATTEMPTS - Maximum number of times to retry on unexpected failures
  • DOCBOX_CONVERT_LAMBDA_RETRY_WAIT - Delay to wait between each retry attempt

Structs

OfficeConvertLambdaConfig
OfficeConverterLambda
Variant of [ConvertToPdf] that uses LibreOffice through a office-converter server for the conversion

Enums

OfficeConvertLambdaConfigError
OfficeConvertLambdaError