pub struct OfficeConvertLambdaConfig {
pub function_name: String,
pub qualifier: Option<String>,
pub tenant_id: Option<String>,
pub retry_attempts: usize,
pub retry_wait: Duration,
pub tmp_bucket: String,
}Fields
function_name: StringThe name or ARN of the Lambda function, version, or alias.
qualifier: Option<String>Specify a version or alias to invoke a published version of the function.
tenant_id: Option<String>The identifier of the tenant in a multi-tenant Lambda function.
retry_attempts: usizeNumber of retry attempts to perform
retry_wait: DurationTime to wait between retry attempts
tmp_bucket: StringTemporary bucket to use for lambda input and output files
Implementations